@@ -20,12 +20,14 @@ command_index = {
     #
     # compute commands
     ('checksum',): 'ctc.cli.commands.compute.checksum_command',
+    ('decode',): 'ctc.cli.commands.compute.decode_command',
     ('keccak',): 'ctc.cli.commands.compute.keccak_command',
     ('lower',): 'ctc.cli.commands.compute.lower_command',
     ('ascii',): 'ctc.cli.commands.compute.ascii_command',
     ('hex',): 'ctc.cli.commands.compute.hex_command',
     #
     # data commands
+    ('abi',): 'ctc.cli.commands.data.abi_command',
     ('address',): 'ctc.cli.commands.data.address_command',
     ('block',): 'ctc.cli.commands.data.block_command',
     ('blocks',): 'ctc.cli.commands.data.blocks_command',
