@@ -8,8 +8,12 @@ def get_command_spec() -> toolcli.CommandSpec:
         'f': hex_command,
         'help': 'convert ascii to hex',
         'args': [
-            {'name': 'data'},
-            {'name': '--raw', 'action': 'store_true'},
+            {'name': 'data', 'help': 'ascii data to convert'},
+            {
+                'name': '--raw',
+                'action': 'store_true',
+                'help': 'omit the "0x" prefix',
+            },
         ],
     }
 
