@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import typing
 
+from ctc import binary
 from ctc import spec
 from . import erc20_generic
 
@@ -13,7 +14,7 @@ from . import erc20_generic
 
 async def async_get_erc20_decimals(
     token: spec.ERC20Reference,
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ) -> int:
     """get decimals of an erc20"""
@@ -24,7 +25,7 @@ async def async_get_erc20_decimals(
 
 async def async_get_erc20s_decimals(
     tokens: typing.Iterable[spec.ERC20Reference],
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ) -> list[int]:
     """get decimals of multiple erc20s"""
@@ -49,7 +50,7 @@ async def async_get_erc20_decimals_by_block(
 
 async def async_get_erc20_name(
     token: spec.ERC20Reference,
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ) -> str:
     """get name of an erc20"""
@@ -60,7 +61,7 @@ async def async_get_erc20_name(
 
 async def async_get_erc20s_names(
     tokens: typing.Iterable[spec.ERC20Reference],
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ) -> list[str]:
     """get name of multiple erc20s"""
@@ -85,26 +86,46 @@ async def async_get_erc20_name_by_block(
 #
 
 
+def _decode_raw_symbol(data):
+    """special case decode of ancient non-compliant implementations of symbol"""
+    if len(data) == 66:
+        return binary.hex_to_ascii(data).strip('\x00')
+    else:
+        as_binary = binary.convert(data, 'binary')
+        return binary.abi_decode(as_binary, '(string)')[0]
+
+
 async def async_get_erc20_symbol(
     token: spec.ERC20Reference,
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ):
     """get symbol of an erc20"""
-    return await erc20_generic.async_erc20_eth_call(
-        function_name='symbol', token=token, block=block, **rpc_kwargs
+
+    result = await erc20_generic.async_erc20_eth_call(
+        function_name='symbol',
+        token=token,
+        block=block,
+        decode_response=False,
+        **rpc_kwargs,
     )
+    return _decode_raw_symbol(result)
 
 
 async def async_get_erc20s_symbols(
     tokens: typing.Iterable[spec.ERC20Reference],
-    block: spec.BlockNumberReference = 'latest',
+    block: typing.Optional[spec.BlockNumberReference] = None,
     **rpc_kwargs
 ):
     """get symbol of multiple erc20s"""
-    return await erc20_generic.async_erc20s_eth_calls(
-        function_name='symbol', tokens=tokens, block=block, **rpc_kwargs
+    results = await erc20_generic.async_erc20s_eth_calls(
+        function_name='symbol',
+        tokens=tokens,
+        block=block,
+        decode_response=False,
+        **rpc_kwargs,
     )
+    return [_decode_raw_symbol(result) for result in results]
 
 
 async def async_get_erc20_symbol_by_block(
@@ -113,7 +134,12 @@ async def async_get_erc20_symbol_by_block(
     **rpc_kwargs
 ):
     """get symbol of an erc20 across multiple blocks"""
-    return await erc20_generic.async_erc20_eth_call_by_block(
-        function_name='symbol', token=token, blocks=blocks, **rpc_kwargs
+    results = await erc20_generic.async_erc20_eth_call_by_block(
+        function_name='symbol',
+        token=token,
+        blocks=blocks,
+        decode_response=False,
+        **rpc_kwargs,
     )
+    return [_decode_raw_symbol(result) for result in results]
 
